@@ -10,6 +10,7 @@ my $app;
 
 multi sub app {
     $app = Bailador::App.new unless $app;
+    $app.config.load-from-env();
     return $app;
 }
 
@@ -85,10 +86,6 @@ sub session-delete is export {
     return app.session-delete();
 }
 
-sub sessions-config is export {
-    return app.sessions-config;
-}
-
 sub uri-for(Str $path) is export {
     return app.request.uri-for($path);
 }
@@ -105,11 +102,34 @@ sub redirect(Str $location) is export {
     app.redirect($location);
 }
 
-sub baile($port = 3000) is export {
-    my $psgi-app = app.get-psgi-app();
-    given HTTP::Easy::PSGI.new(:host<0.0.0.0>, :$port) {
-        .app($psgi-app);
-        say "Entering the development dance floor: http://0.0.0.0:$port";
-        .run;
+# for Dancer2 compatibility
+sub set(Str $key, $value) is export {
+    app.config."$key"() = $value;
+}
+
+sub config() is export {
+    return app.config;
+}
+
+sub add-command-ns(Str:D $namespace) is export {
+    app.commands.add-ns($namespace);
+}
+
+multi sub baile() is export {
+    my $cmd;
+    if @*ARGS.elems > 0 {
+        $cmd = app.commands.get-command(@*ARGS.shift);
+        app.config.load-from-args(@*ARGS),
+    } elsif app.config.command-detection() {
+        $cmd = app.commands.detect-command();
+    } else {
+        die 'can not detect command';
     }
+    $cmd.run(app => app() );
+}
+
+multi sub baile(Str :$command!, *@args) is export {
+    my $cmd = app.commands.get-command($command);
+    app.config.load-from-args(@args),
+    $cmd.run(app => app() );
 }
